@@ -10,16 +10,18 @@
 #include <QObject>
 #include <QSharedPointer>
 
+#include "processcore_export.h"
+
 namespace KSysGuard
 {
 class ProcessAttribute;
 
-class Q_DECL_EXPORT ExtendedProcesses : public KSysGuard::Processes
+class PROCESSCORE_EXPORT ExtendedProcesses : public KSysGuard::Processes
 {
     Q_OBJECT
 public:
-    QVector<ProcessAttribute *> attributes() const;
-    QVector<ProcessAttribute *> extendedAttributes() const;
+    QList<ProcessAttribute *> attributes() const;
+    QList<ProcessAttribute *> extendedAttributes() const;
 
     /**
      * Returns a single shared instance of the process list for when used in multiple views
